<?php

class SitemapForm extends Form
{

	public function __construct()
	{

		$this->add(array(
			'name' => 'contentCb',
			'type' => 'checkbox',
			'value' => 0,
			'label' => '',
		));

		$this->add(array(
			'name' => 'looseCb',
			'type' => 'checkbox',
			'value' => 0,
			'label' => '',
		));

		$this->add(array(
			'name' => 'smCode',
			'type' => 'text',
			'value' => '',
			'label' => 'Sitemap code or title',
			'guide' => 'Unique code or title for the current sitemap.',
			'required' => true,
			'validation' => 'shortText',
		));

		$this->add(array(
			'name' => 'smFileName',
			'type' => 'text',
			'value' => '',
			'label' => 'Sitemap file name',
			'guide' => '',
			'required' => true,
			'validation' => 'path',
		));

		$this->add(array(
			'name' => 'smPath',
			'type' => 'text',
			'value' => 'custom/sitemaps',
			'label' => 'Sitemap path',
			'guide' => 'Directory path to current sitemap.',
			'required' => true,
			'validation' => 'path',
		));

		$this->add(array(
			'name' => 'customDataStart',
            'type'  => 'textarea',
            'label' => 'Custom XML, starting code: ',
				'guide' => 'Custom sitemap XML code (if any) before the code, which will be created automatically (if any). This code can include up to 2000 characters. You can use here for example module method URL code wrapped with url tags or index file code wrapped with sitemap tags.',
				'required' => false,
				'attributes'  => array(
					'id' => 'customDataStart',
					'rows' => '6',
					'cols' => '80',
				),
				'validation' => 'smallTextarea',
		));

		$this->add(array(
			'name' => 'output',
            'type'  => 'textarea',
            'label' => 'XML code of the sitemap: ',
				'guide' => 'XML code of the sitemap as it would be in the XML file. You can not change the XML code in this text area. Use custom data areas and other form fields to change the XML code.',
				'required' => false,
				'attributes'  => array(
					'id' => 'output',
					'rows' => '6',
					'cols' => '80',
				),
//				'validation' => 'smallTextarea',
		));

		$this->add(array(
			'name' => 'customDataEnd',
            'type'  => 'textarea',
            'label' => 'Custom XML, ending code: ',
				'guide' => 'Custom sitemap XML code (if any) after the code, which will be created automatically (if any). This code can include up to 2000 characters. You can use here for example module method URL code wrapped with url tags or index file code wrapped with sitemap tags.',
				'required' => false,
				'attributes'  => array(
					'id' => 'customDataEnd',
					'rows' => '6',
					'cols' => '80',
				),
				'validation' => 'smallTextarea',
		));

		$this->add(array(
			'name' => 'changeFreq',
			'type' => 'select',
			'options' => array(
				'None' => 'None',
				'always' => 'always',
				'hourly' => 'hourly',
				'daily' => 'daily',
				'weekly' => 'weekly',
				'monthly' => 'monthly',
				'yearly' => 'yearly',
				'never' => 'never',
			),
			'attributes'  => array(
				'style' => 'width:260px',
			),
			'value' => 'daily',
			'label' => 'Page changing frequency: ',
			'guide' => 'Value of changefreq tags in sitemap XML format. If None is chosen, then these tags will be omitted.',
		));


		$this->add(array(
			'name' => 'lastMod',
			'type' => 'select',
			'options' => array(
				'None' => 'None',
				'Date' => 'Date',
//				'DateAndTime' => 'Date and time',
			),
			'attributes'  => array(
				'style' => 'width:260px',
			),
			'value' => 'Date',
			'label' => 'Last modified: ',
//			'guide' => 'If and how the tags <lastmod> are used in sitemap XML format. If None is chosen, then these tags will be omitted.',
			'guide' => 'Choose, whether the lastmod tags are used in sitemap XML format. If None is chosen, then these tags will be omitted, otherwise date will be shown in the tags.',
		));

		$this->add(array(
			'name' => 'priorSwitch',
			'type' => 'select',
			'options' => array(
				'Disabled' => 'Disabled',
				'Enabled' => 'Enabled',
//				'DateAndTime' => 'Date and time',
			),
			'attributes'  => array(
				'style' => 'width:260px',
			),
			'value' => 'Enabled',
			'label' => 'Hide/show priority tags: ',
//			'guide' => 'If and how the tags <lastmod> are used in sitemap XML format. If None is chosen, then these tags will be omitted.',
			'guide' => 'Choose, whether the priority tags are used in sitemap XML format. If Disabled is chosen, then these tags will be omitted.',
		));

		$this->add(array(
			'name' => 'fileType',
			'type' => 'select',
			'options' => array(
				'urlSet' => 'URL set file',
				'index' => 'Index file',
//				'DateAndTime' => 'Date and time',
			),
			'attributes'  => array(
				'style' => 'width:260px',
			),
			'value' => 'urlSet',
			'label' => 'Type of sitemap XML file: ',
//			'guide' => 'If and how the tags <lastmod> are used in sitemap XML format. If None is chosen, then these tags will be omitted.',
			'guide' => '',
		));

		$this->add(array(
			'name' => 'save',
			'type' => 'submit',
			'value' => 'Save',
			'id' => 'save',
		));

		$this->add(array(
			'name' => 'saveFile',
			'type' => 'submit',
			'value' => 'Update XML file',
			'id' => 'saveFile',
		));


		$this->add(array(
			'name' => 'begin',
			'type'  => 'begin',
			'value' => '#',
			'id' => 'begin',
			'attributes'  => array(
				'method' => 'post',
			),
		));

		$this->add(array(
			'name' => 'end',
			'type'  => 'end',
		));

		$this->add(array(
			'name' => 'id',
			'type'  => 'hidden',
			'value'  => '',
		));

	}

	public function convertDbData($dbData)
	{

		$this->setValue('smCode',$dbData['smCode']);
		$this->setValue('smPath',$dbData['smPath']);
		$this->setValue('smFileName',$dbData['smFileName']);
		$this->setValue('fileType',$dbData['fileType']);
		$this->setValue('changeFreq',$dbData['changeFreq']);
		$this->setValue('lastMod',$dbData['lastMod']);
		$this->setValue('priorSwitch',$dbData['priorSwitch']);

	}

}
